import { Button, BaseButton, InlineButton } from "./Button";
import { IKeyboardButton } from "../../types/IKeyboard";
import { IMessageSendParams } from "../../types/params/ISendParams";
export declare abstract class BaseKeyboardBuilder<TButton extends BaseButton> {
    protected buttons: TButton[][];
    add(btn: TButton): this;
    wrap(): this;
    clear(): void;
    abstract createButton(...args: any[]): this;
    abstract build(): Pick<IMessageSendParams, "reply_markup">;
}
export declare class InlineKeyboardBuilder extends BaseKeyboardBuilder<InlineButton> {
    createButton(...args: ConstructorParameters<typeof InlineButton>): this;
    build(): {
        reply_markup: {
            inline_keyboard: import("../../types/IKeyboard").IKeyboardInlineButton[][];
        };
    };
}
export declare class KeyboardBuilder extends BaseKeyboardBuilder<Button> {
    private additionalOptions;
    setResize(state?: boolean): this;
    setOneTime(state?: boolean): this;
    setSelective(state?: boolean): this;
    setPlaceholder(text: string): this;
    createButton(...args: ConstructorParameters<typeof Button>): this;
    build(): {
        reply_markup: {
            text?: string;
            request_user?: {
                request_id: number;
                user_is_bot?: boolean;
                user_is_premium?: boolean;
            };
            request_chat?: {
                request_id: number;
                chat_is_channel: boolean;
                chat_is_forum?: boolean;
                chat_has_username?: boolean;
                chat_is_created?: boolean;
                bot_is_member?: boolean;
            };
            request_contact?: boolean;
            request_location?: boolean;
            request_poll?: {
                type: "regular" | "quiz";
            };
            keyboard: IKeyboardButton[][];
        };
    };
    static remove(remove?: boolean, selective?: boolean): string;
}
